mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Philipp Hortmann <philipp.g.hortmann@gmail.com>
To: Forest Bond <forest@alittletooquiet.net>,
	Greg Kroah-Hartman <gregkh@linuxfoundation.org>,
	linux-staging@lists.linux.dev, linux-kernel@vger.kernel.org
Subject: [PATCH 07/12] staging: vt6655: Rename function MACbSafeStop
Date: Sun, 11 Sep 2022 12:46:35 +0200	[thread overview]
Message-ID: <5c91b281dfab75e5ccf13413232ec993a8056af8.1662890990.git.philipp.g.hortmann@gmail.com> (raw)
In-Reply-To: <cover.1662890990.git.philipp.g.hortmann@gmail.com>

Rename function MACbSafeStop to vt6655_mac_safe_stop to avoid CamelCase
which is not accepted by checkpatch.pl. Remove unnecessary declaration
of function and make function static.

Signed-off-by: Philipp Hortmann <philipp.g.hortmann@gmail.com>
---
 drivers/staging/vt6655/mac.c | 6 +++---
 drivers/staging/vt6655/mac.h | 1 -
 2 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/drivers/staging/vt6655/mac.h b/drivers/staging/vt6655/mac.h
index 12b4f8937d14..c6147a4f563e 100644
--- a/drivers/staging/vt6655/mac.h
+++ b/drivers/staging/vt6655/mac.h
@@ -554,7 +554,6 @@ void vt6655_mac_set_short_retry_limit(struct vnt_private *priv, unsigned char re
 void MACvSetLongRetryLimit(struct vnt_private *priv, unsigned char byRetryLimit);
 
 bool MACbSoftwareReset(struct vnt_private *priv);
-bool MACbSafeStop(struct vnt_private *priv);
 bool MACbShutdown(struct vnt_private *priv);
 void MACvInitialize(struct vnt_private *priv);
 void MACvSetCurrRx0DescAddr(struct vnt_private *priv,
diff --git a/drivers/staging/vt6655/mac.c b/drivers/staging/vt6655/mac.c
index 24851fe53683..e1f639787316 100644
--- a/drivers/staging/vt6655/mac.c
+++ b/drivers/staging/vt6655/mac.c
@@ -19,7 +19,7 @@
  *      MACbSoftwareReset - Software Reset MAC
  *      vt6655_mac_safe_rx_off - Turn Off MAC Rx
  *      vt6655_mac_safe_tx_off - Turn Off MAC Tx
  *      MACbSafeStop - Stop MAC function
  *      MACbShutdown - Shut down MAC
  *      MACvInitialize - Initialize MAC
  *      MACvSetCurrRxDescAddr - Set Rx Descriptors Address
@@ -432,7 +432,7 @@ static bool vt6655_mac_safe_tx_off(struct vnt_private *priv)
  * Return Value: true if success; otherwise false
  *
  */
-bool MACbSafeStop(struct vnt_private *priv)
+static bool vt6655_mac_safe_stop(struct vnt_private *priv)
 {
 	void __iomem *io_base = priv->port_offset;
 
@@ -474,7 +474,7 @@ bool MACbShutdown(struct vnt_private *priv)
 	iowrite32(0, io_base + MAC_REG_IMR);
 	vt6655_mac_set_loopback_mode(priv, MAC_LB_INTERNAL);
 	/* stop the adapter */
-	if (!MACbSafeStop(priv)) {
+	if (!vt6655_mac_safe_stop(priv)) {
 		vt6655_mac_set_loopback_mode(priv, MAC_LB_NONE);
 		return false;
 	}
@@ -19,7 +19,7 @@
  *      vt6655_mac_safe_rx_off - Turn Off MAC Rx
  *      vt6655_mac_safe_tx_off - Turn Off MAC Tx
- *      MACbSafeStop - Stop MAC function
+ *      vt6655_mac_safe_stop - Stop MAC function
  *      MACbShutdown - Shut down MAC
  *      MACvInitialize - Initialize MAC
-- 
2.37.3


  parent reply	other threads:[~2022-09-11 10:47 UTC|newest]

Thread overview: 16+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-09-11 10:45 [PATCH 00/12] staging: vt6655: Cleanup and rename functions of mac.h Philipp Hortmann
2022-09-11 10:45 ` [PATCH 01/12] staging: vt6655: Cleanup and rename function MACvSetLoopbackMode Philipp Hortmann
2022-09-11 10:45 ` [PATCH 02/12] staging: vt6655: Cleanup and rename function MACvSaveContext Philipp Hortmann
2022-09-11 10:45 ` [PATCH 03/12] staging: vt6655: Cleanup and rename function MACvRestoreContext Philipp Hortmann
2022-09-11 10:46 ` [PATCH 04/12] staging: vt6655: Cleanup and rename function MACbSafeSoftwareReset Philipp Hortmann
2022-09-13 10:12   ` Dan Carpenter
2022-09-13 18:26     ` Philipp Hortmann
2022-09-14 14:47       ` Dan Carpenter
2022-09-11 10:46 ` [PATCH 05/12] staging: vt6655: Rename function MACbSafeRxOff Philipp Hortmann
2022-09-11 10:46 ` [PATCH 06/12] staging: vt6655: Rename function MACbSafeTxOff Philipp Hortmann
2022-09-11 10:46 ` Philipp Hortmann [this message]
2022-09-11 10:46 ` [PATCH 08/12] staging: vt6655: Rename function MACvSetCurrRx0DescAddr Philipp Hortmann
2022-09-11 10:47 ` [PATCH 09/12] staging: vt6655: Rename function MACvSetCurrRx1DescAddr Philipp Hortmann
2022-09-11 10:47 ` [PATCH 10/12] staging: vt6655: Cleanup and rename function MACvSetCurrTXDescAddr Philipp Hortmann
2022-09-11 10:47 ` [PATCH 11/12] staging: vt6655: Rename function MACvSetCurrTx0DescAddrEx Philipp Hortmann
2022-09-11 10:47 ` [PATCH 12/12] staging: vt6655: Rename function MACvSetCurrAC0DescAddrEx Philipp Hortmann

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=5c91b281dfab75e5ccf13413232ec993a8056af8.1662890990.git.philipp.g.hortmann@gmail.com \
    --to=philipp.g.hortmann@gmail.com \
    --cc=forest@alittletooquiet.net \
    --cc=gregkh@linuxfoundation.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-staging@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®